import { ITaggable, TagManager } from "aws-cdk-lib";
import * as cloudwatch from "aws-cdk-lib/aws-cloudwatch";
import { Construct } from "constructs";
/**
 * @internal
 */
export interface HealthCheckOptions {
    /**
     * The display name of this Route53 HealthCheck
     */
    readonly healthCheckName?: string;
    /**
     * Whether to invert the status of the Route53 health check status.
     */
    readonly inverted?: boolean;
}
export interface IHealthCheck {
    /**
     * Return the given named metric for this HealthCheck.
     */
    metric(metricName: string, props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    /**
     * Route53 health checkers report that the HealthCheck is healthy or unhealthy.
     */
    metricHealthCheckStatus(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
}
/**
 * @internal
 */
export declare abstract class HealthCheckBase extends Construct implements IHealthCheck, ITaggable {
    abstract readonly healthCheckId: string;
    readonly tags: TagManager;
    /**
     * Return the given named metric for this HealthCheck.
     */
    metric(metricName: string, props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    /**
     * Route53 health checkers report that the HealthCheck is healthy or unhealthy.
     */
    metricHealthCheckStatus(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
}
/**
 * The type of health check to create.
 */
export declare enum HealthCheckType {
    HTTP = "HTTP",
    HTTPS = "HTTPS",
    HTTP_STR_MATCH = "HTTP_STR_MATCH",
    HTTPS_STR_MATCH = "HTTPS_STR_MATCH",
    TCP = "TCP",
    CALCULATED = "CALCULATED",
    CLOUDWATCH_METRIC = "CLOUDWATCH_METRIC",
    RECOVERY_CONTROL = "RECOVERY_CONTROL"
}
export declare enum InsufficientDataHealthStatus {
    HEALTHY = "Healthy",
    UNHEALTHY = "Unhealthy",
    LAST_KNOWN_STATUS = "LastKnownStatus"
}
